@@ -20,6 +20,9 @@ class KAlgebraExpression : public Cantor::Expression
 
         void evaluate() override;
         void interrupt() override;
+
+        void parseOutput(const QString&) override {};
+        void parseError(const QString&) override {};
 };
 
 #endif
