@@ -18,16 +18,13 @@
 #include "qalculatesession.h"
 #include "qalculatesyntaxhelpobject.h"
 
-#include <libqalculate/Calculator.h>
 #include <libqalculate/ExpressionItem.h>
 #include <libqalculate/Unit.h>
 #include <libqalculate/Prefix.h>
 #include <libqalculate/Variable.h>
 #include <libqalculate/Function.h>
 
-#include <string>
 // required for the plotting interface of Qalculator
-#include <vector>
 
 #include <QDir>
 #include <QTemporaryFile>
@@ -93,7 +90,7 @@ void QalculateExpression::parseOutput(const QString& output)
     resultStr.remove(QLatin1String(">"));
     resultStr = resultStr.trimmed();
 
-    qDebug() << "output from qalc for command: " << command() << " " << resultStr << endl;
+    qDebug() << "output from qalc for command: " << command() << " " << resultStr;
     setResult(new Cantor::TextResult(resultStr));
     // update the variable model
     updateVariables();
@@ -116,7 +113,7 @@ void QalculateExpression::parseError(const QString& error)
     QString errorStr = error;
     errorStr.remove(QLatin1String(">"));
     errorStr  = errorStr.trimmed();
-    qDebug() << "Error from qalc for command: " << command() <<  " " << error << endl;
+    qDebug() << "Error from qalc for command: " << command() <<  " " << error;
     setErrorMessage(errorStr);
     setStatus(Cantor::Expression::Error);
 }
