@@ -4,7 +4,6 @@
 */
 
 #include "scilabsession.h"
-#include "scilabexpression.h"
 #include "scilabhighlighter.h"
 #include "scilabcompletionobject.h"
 
@@ -98,8 +97,8 @@ void ScilabSession::login()
     QObject::connect(m_process, &QProcess::readyReadStandardOutput, this, &ScilabSession::readOutput);
     QObject::connect(m_process, &QProcess::readyReadStandardError, this, &ScilabSession::readError);
 
-    m_process->readAllStandardOutput().clear();
-    m_process->readAllStandardError().clear();
+    m_process->readAllStandardOutput();
+    m_process->readAllStandardError();
 
     changeStatus(Cantor::Session::Done);
 
@@ -254,6 +253,7 @@ void ScilabSession::plotFileChanged(const QString& filename)
     }
 }
 
+//TODO: unify with the funcion in the base class
 void ScilabSession::currentExpressionStatusChanged(Cantor::Expression::Status status)
 {
     qDebug() << "currentExpressionStatusChanged: " << status;
